#!/usr/bin/python
# -*- coding: utf-8 -*-

import setuptools

with open("README.md", "r") as fh:
  long_description = fh.read()

setuptools.setup(
    name="dasb_translator",
    version="0.0.1",
    author="Hompeaz",
    author_email="hompeaz@gmail.com",
    description="A CLI translation tool by reading the clipboard",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Acoustical/Dasb_Translator",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
    install_requires=[
        "requests",
        "pyperclip",
        "deepl"
    ],
    entry_points={
        'console_scripts': [
            'dasb_translator = dasb_translator:main',
        ],
    }
)



#!/usr/bin/python
# -*- coding:utf-8 -*-

from deepl import deepl
import pyperclip
import time
import sys
import os

replace_list = [
    ["-\r\n-", ""],
    ["-\r\n", ""],
    ["\r\n-", ""],
    ["\r\n", " "],
    ["-\n-", ""],
    ["-\n", ""],
    ["\n-", ""],
    ["\n", " "]
]

def translate(sentences):

    t = deepl.DeepLCLI("en", "zh")
    print("\033[1;34m"+sentences+"\n\033[0m")

    result = t.translate(sentences)

    print("\033[1;32m"+result+"\n\033[0m")
    print("#################")

    del t

def main():
    prv = ''
    pyperclip.copy('')
    sys.stderr = open(os.devnull, 'w')
    print('大帅比！Deepl 翻译引擎已开启，你来复制，我来翻译！' + '\n')
    print("#################")
    try:
        while(True):
            time.sleep(1)
            new = pyperclip.paste()
            for r in replace_list:
                new.replace(r[0], r[1])
            pyperclip.copy(new)
            if len(new) > 0 and new != prv:
                translate(new)
                prv = new
    except:
        pass            

if __name__ == '__main__':
    main()
